<?php

namespace Litecms\CouponCode\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\CouponCode\Models\CouponCode;

class CouponCodePolicy
{

    /**
     * Determine if the given user can view the coupon_code.
     *
     * @param UserPolicy $user
     * @param CouponCode $coupon_code
     *
     * @return bool
     */
    public function view(UserPolicy $user, CouponCode $coupon_code)
    {
        if ($user->canDo('coupon_code.coupon_code.view') && $user->isAdmin()) {
            return true;
        }

        return $coupon_code->user_id == user_id() && $coupon_code->user_type == user_type();
    }

    /**
     * Determine if the given user can create a coupon_code.
     *
     * @param UserPolicy $user
     * @param CouponCode $coupon_code
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('coupon_code.coupon_code.create');
    }

    /**
     * Determine if the given user can update the given coupon_code.
     *
     * @param UserPolicy $user
     * @param CouponCode $coupon_code
     *
     * @return bool
     */
    public function update(UserPolicy $user, CouponCode $coupon_code)
    {
        if ($user->canDo('coupon_code.coupon_code.edit') && $user->isAdmin()) {
            return true;
        }

        return $coupon_code->user_id == user_id() && $coupon_code->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given coupon_code.
     *
     * @param UserPolicy $user
     * @param CouponCode $coupon_code
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CouponCode $coupon_code)
    {
        return $coupon_code->user_id == user_id() && $coupon_code->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given coupon_code.
     *
     * @param UserPolicy $user
     * @param CouponCode $coupon_code
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CouponCode $coupon_code)
    {
        if ($user->canDo('coupon_code.coupon_code.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given coupon_code.
     *
     * @param UserPolicy $user
     * @param CouponCode $coupon_code
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CouponCode $coupon_code)
    {
        if ($user->canDo('coupon_code.coupon_code.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
