<?php

namespace Litecms\CouponCode\Providers;

use Illuminate\Support\ServiceProvider;

class CouponCodeServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'coupon_code');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'coupon_code');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.coupon_code', function ($app) {
            return $this->app->make('Litecms\CouponCode\CouponCode');
        });

                // Bind CouponCode to repository
        $this->app->bind(
            'Litecms\CouponCode\Interfaces\CouponCodeRepositoryInterface',
            \Litecms\CouponCode\Repositories\Eloquent\CouponCodeRepository::class
        );

        $this->app->register(\Litecms\CouponCode\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\CouponCode\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\CouponCode\Providers\RouteServiceProvider::class);
                $this->app->register(\Litecms\CouponCode\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.coupon_code'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/coupon_code.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/coupon_code')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/coupon_code')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
